Does the model list refer to another model in the model list?
Source:R/tar_nlmixr_multimodel.R
tar_nlmixr_multimodel_has_self_reference.RdDoes the model list refer to another model in the model list?
Usage
tar_nlmixr_multimodel_has_self_reference(model_list, name)
tar_nlmixr_multimodel_has_self_reference_single(model, name)Arguments
- model_list
A named list of calls for model targets to be created
- name
Symbol, name of the target. In
tar_target(),nameis an unevaluated symbol, e.g.tar_target(name = data). Intar_target_raw(),nameis a character string, e.g.tar_target_raw(name = "data").A target name must be a valid name for a symbol in R, and it must not start with a dot. Subsequent targets can refer to this name symbolically to induce a dependency relationship: e.g.
tar_target(downstream_target, f(upstream_target))is a target nameddownstream_targetwhich depends on a targetupstream_targetand a functionf().In most cases, The target name is the name of its local data file in storage. Some file systems are not case sensitive, which means converting a name to a different case may overwrite a different target. Please ensure all target names have unique names when converted to lower case.
In addition, a target's name determines its random number generator seed. In this way, each target runs with a reproducible seed so someone else running the same pipeline should get the same results, and no two targets in the same pipeline share the same seed. (Even dynamic branches have different names and thus different seeds.) You can recover the seed of a completed target with
tar_meta(your_target, seed)and runtar_seed_set()on the result to locally recreate the target's initial RNG state.- model
A single model call for the model target to be created