Generate a list of models based on a single dataset and estimation method
Source:R/tar_nlmixr_multimodel.R
tar_nlmixr_multimodel.RdGenerate a list of models based on a single dataset and estimation method
Usage
tar_nlmixr_multimodel(
name,
...,
data,
est,
control = list(),
table = nlmixr2est::tableControl(),
env = parent.frame(),
error = c("stop", "continue"),
format = targets::tar_option_get("format"),
repository = targets::tar_option_get("repository"),
library = targets::tar_option_get("library"),
memory = targets::tar_option_get("memory"),
garbage_collection = isTRUE(targets::tar_option_get("garbage_collection")),
deployment = targets::tar_option_get("deployment"),
resources = targets::tar_option_get("resources"),
storage = targets::tar_option_get("storage"),
retrieval = targets::tar_option_get("retrieval"),
cue = targets::tar_option_get("cue")
)Arguments
- name
Symbol, name of the target. In
tar_target(),nameis an unevaluated symbol, e.g.tar_target(name = data). Intar_target_raw(),nameis a character string, e.g.tar_target_raw(name = "data").A target name must be a valid name for a symbol in R, and it must not start with a dot. Subsequent targets can refer to this name symbolically to induce a dependency relationship: e.g.
tar_target(downstream_target, f(upstream_target))is a target nameddownstream_targetwhich depends on a targetupstream_targetand a functionf().In most cases, The target name is the name of its local data file in storage. Some file systems are not case sensitive, which means converting a name to a different case may overwrite a different target. Please ensure all target names have unique names when converted to lower case.
In addition, a target's name determines its random number generator seed. In this way, each target runs with a reproducible seed so someone else running the same pipeline should get the same results, and no two targets in the same pipeline share the same seed. (Even dynamic branches have different names and thus different seeds.) You can recover the seed of a completed target with
tar_meta(your_target, seed)and runtar_seed_set()on the result to locally recreate the target's initial RNG state.- ...
Named arguments with the format
"Model description" = modelFunction- data
nlmixr data
- est
estimation method (all methods are shown by `nlmixr2AllEst()`). Methods can be added for other tools
- control
The estimation control object. These are expected to be different for each type of estimation method
- table
The output table control object (like `tableControl()`)
- env
The environment where the model is setup (not needed for typical use)
- error
What should happen if the estimation step throws an error?
"stop"(the default) lets the error propagate, haltingtargets::tar_make()as usual."continue"catches the error and stores a failure sentinel (an object of classnlmixr2targetsError, which also inherits from"try-error") carrying the error message, so a single failed model does not stop the rest of the pipeline. Detect a failed fit withinherits(fit, "nlmixr2targetsError")or the broaderinherits(fit, "try-error").- format
Optional storage format for the target's return value. With the exception of
format = "file", each target gets a file in_targets/objects, and each format is a different way to save and load this file. See the "Storage formats" section for a detailed list of possible data storage formats.- repository
Character of length 1, remote repository for target storage. Choices:
"local": file system of the local machine."aws": Amazon Web Services (AWS) S3 bucket. Can be configured with a non-AWS S3 bucket using theendpointargument oftar_resources_aws(), but versioning capabilities may be lost in doing so. See the cloud storage section of https://books.ropensci.org/targets/data.html for details for instructions."gcp": Google Cloud Platform storage bucket. See the cloud storage section of https://books.ropensci.org/targets/data.html for details for instructions.A character string from
tar_repository_cas()for content-addressable storage.
Note: if
repositoryis not"local"andformatis"file"then the target should create a single output file. That output file is uploaded to the cloud and tracked for changes where it exists in the cloud. As oftargetsversion 1.11.0 and higher, the local file is no longer deleted after the target runs.- library
Character vector of library paths to try when loading
packages.- memory
Character of length 1, memory strategy. Possible values:
"auto"(default): equivalent tomemory = "transient"in almost all cases. But to avoid superfluous reads from disk,memory = "auto"is equivalent tomemory = "persistent"for for non-dynamically-branched targets that other targets dynamically branch over. For example: if your pipeline hastar_target(name = y, command = x, pattern = map(x)), thentar_target(name = x, command = f(), memory = "auto")will use persistent memory forxin order to avoid rereading all ofxfor every branch ofy."transient": the target gets unloaded after every new target completes. Either way, the target gets automatically loaded into memory whenever another target needs the value."persistent": the target stays in memory until the end of the pipeline (unlessstorageis"worker", in which casetargetsunloads the value from memory right after storing it in order to avoid sending copious data over a network).
For cloud-based file targets (e.g.
format = "file"withrepository = "aws"), thememoryoption applies to the temporary local copy of the file:"persistent"means it remains until the end of the pipeline and is then deleted, and"transient"means it gets deleted as soon as possible. The former conserves bandwidth, and the latter conserves local storage.- garbage_collection
Logical:
TRUEto runbase::gc()just before the target runs, in whatever R process it is about to run (which could be a parallel worker).FALSEto omit garbage collection. Numeric values get converted toFALSE. Thegarbage_collectionoption intar_option_set()is independent of the argument of the same name intar_target().- deployment
Character of length 1. If
deploymentis"main", then the target will run on the central controlling R process. Otherwise, ifdeploymentis"worker"and you set up the pipeline with distributed/parallel computing, then the target runs on a parallel worker. For more on distributed/parallel computing intargets, please visit https://books.ropensci.org/targets/crew.html.- resources
Object returned by
tar_resources()with optional settings for high-performance computing functionality, alternative data storage formats, and other optional capabilities oftargets. Seetar_resources()for details.- storage
Character string to control when the output of the target is saved to storage. Only relevant when using
targetswith parallel workers (https://books.ropensci.org/targets/crew.html). Must be one of the following values:"worker"(default): the worker saves/uploads the value."main": the target's return value is sent back to the host machine and saved/uploaded locally."none":targetsmakes no attempt to save the result of the target to storage in the location wheretargetsexpects it to be. Saving to storage is the responsibility of the user. Use with caution.
- retrieval
Character string to control when the current target loads its dependencies into memory before running. (Here, a "dependency" is another target upstream that the current one depends on.) Only relevant when using
targetswith parallel workers (https://books.ropensci.org/targets/crew.html). Must be one of the following values:"auto"(default): equivalent toretrieval = "worker"in almost all cases. But to avoid unnecessary reads from disk,retrieval = "auto"is equivalent toretrieval = "main"for dynamic branches that branch over non-dynamic targets. For example: if your pipeline hastar_target(x, command = f()), thentar_target(y, command = x, pattern = map(x), retrieval = "auto")will use"main"retrieval in order to avoid rereading all ofxfor every branch ofy."worker": the worker loads the target's dependencies."main": the target's dependencies are loaded on the host machine and sent to the worker before the target runs."none":targetsmakes no attempt to load its dependencies. Withretrieval = "none", loading dependencies is the responsibility of the user. Use with caution.
- cue
An optional object from
tar_cue()to customize the rules that decide whether the target is up to date.
See also
tar_nlmixr() for fitting a single model.
Examples
pheno <- function() {
ini({
lcl <- log(0.008); label("Typical value of clearance")
lvc <- log(0.6); label("Typical value of volume of distribution")
etalcl + etalvc ~ c(1,
0.01, 1)
cpaddSd <- 0.1; label("residual variability")
})
model({
cl <- exp(lcl + etalcl)
vc <- exp(lvc + etalvc)
kel <- cl / vc
d / dt(central) <- -kel * central
cp <- central / vc
cp ~ add(cpaddSd)
})
}
pheno2 <- function() {
ini({
lcl <- log(0.008); label("Typical value of clearance")
lvc <- log(0.6); label("Typical value of volume of distribution")
etalcl + etalvc ~ c(2,
0.01, 2)
cpaddSd <- 3.0; label("residual variability")
})
model({
cl <- exp(lcl + etalcl)
vc <- exp(lvc + etalvc)
kel <- cl / vc
d / dt(central) <- -kel * central
cp <- central / vc
cp ~ add(cpaddSd)
})
}
# Build the per-model target chains plus the combined list target.
# Estimation runs only when `targets::tar_make()` is invoked from a
# project whose store you have configured (see `?tar_nlmixr` for one
# tempdir-based setup).
tar_nlmixr_multimodel(
name = all_models,
data = nlmixr2data::pheno_sd,
est = "saem",
"Base model" = pheno,
"Alternative residual error" = pheno2
)
#> [[1]]
#> [[1]]$object_simple
#> <tar_stem>
#> name: all_models_8ae20c5c_object_simple
#> description:
#> command:
#> nlmixr_object_simplify(object = pheno, directory = file.path(targets::tar_config_get("store"),
#> "user/nlmixr2"))
#> format: rds
#> repository: local
#> iteration method: vector
#> error mode: stop
#> memory mode: auto
#> storage mode: worker
#> retrieval mode: auto
#> deployment mode: worker
#> priority: 0
#> resources:
#> list()
#> cue:
#> seed: TRUE
#> file: TRUE
#> iteration: TRUE
#> repository: TRUE
#> format: TRUE
#> depend: TRUE
#> command: TRUE
#> mode: thorough
#> packages:
#> nlmixr2targets
#> nlmixr2est
#> library:
#> NULL
#> [[1]]$data_simple
#> <tar_stem>
#> name: all_models_8ae20c5c_data_simple
#> description:
#> command:
#> nlmixr_data_simplify(object = all_models_8ae20c5c_object_simple,
#> data = nlmixr2data::pheno_sd, table = nlmixr2est::tableControl(),
#> directory = file.path(targets::tar_config_get("store"), "user/nlmixr2"),
#> est = "saem", control = list())
#> format: rds
#> repository: local
#> iteration method: vector
#> error mode: stop
#> memory mode: auto
#> storage mode: worker
#> retrieval mode: auto
#> deployment mode: worker
#> priority: 0
#> resources:
#> list()
#> cue:
#> seed: TRUE
#> file: TRUE
#> iteration: TRUE
#> repository: TRUE
#> format: TRUE
#> depend: TRUE
#> command: TRUE
#> mode: thorough
#> packages:
#> nlmixr2targets
#> nlmixr2est
#> library:
#> NULL
#> [[1]]$fit_simple
#> <tar_stem>
#> name: all_models_8ae20c5c_fit_simple
#> description:
#> command:
#> nlmixr2_indirect(object = all_models_8ae20c5c_object_simple,
#> data = all_models_8ae20c5c_data_simple, est = "saem", control = list(),
#> directory = file.path(targets::tar_config_get("store"), "user/nlmixr2"),
#> error = "stop")
#> format: rds
#> repository: local
#> iteration method: vector
#> error mode: stop
#> memory mode: auto
#> storage mode: worker
#> retrieval mode: auto
#> deployment mode: worker
#> priority: 0
#> resources:
#> list()
#> cue:
#> seed: TRUE
#> file: TRUE
#> iteration: TRUE
#> repository: TRUE
#> format: TRUE
#> depend: TRUE
#> command: TRUE
#> mode: thorough
#> packages:
#> nlmixr2targets
#> nlmixr2est
#> library:
#> NULL
#> [[1]]$fit
#> <tar_stem>
#> name: all_models_8ae20c5c
#> description:
#> command:
#> nlmixr_object_complicate(fit = all_models_8ae20c5c_fit_simple,
#> object = pheno, data = nlmixr2data::pheno_sd)
#> format: rds
#> repository: local
#> iteration method: vector
#> error mode: stop
#> memory mode: auto
#> storage mode: worker
#> retrieval mode: auto
#> deployment mode: worker
#> priority: 0
#> resources:
#> list()
#> cue:
#> seed: TRUE
#> file: TRUE
#> iteration: TRUE
#> repository: TRUE
#> format: TRUE
#> depend: TRUE
#> command: TRUE
#> mode: thorough
#> packages:
#> nlmixr2targets
#> nlmixr2est
#> library:
#> NULL
#>
#> [[2]]
#> [[2]]$object_simple
#> <tar_stem>
#> name: all_models_b0a374c4_object_simple
#> description:
#> command:
#> nlmixr_object_simplify(object = pheno2, directory = file.path(targets::tar_config_get("store"),
#> "user/nlmixr2"))
#> format: rds
#> repository: local
#> iteration method: vector
#> error mode: stop
#> memory mode: auto
#> storage mode: worker
#> retrieval mode: auto
#> deployment mode: worker
#> priority: 0
#> resources:
#> list()
#> cue:
#> seed: TRUE
#> file: TRUE
#> iteration: TRUE
#> repository: TRUE
#> format: TRUE
#> depend: TRUE
#> command: TRUE
#> mode: thorough
#> packages:
#> nlmixr2targets
#> nlmixr2est
#> library:
#> NULL
#> [[2]]$data_simple
#> <tar_stem>
#> name: all_models_b0a374c4_data_simple
#> description:
#> command:
#> nlmixr_data_simplify(object = all_models_b0a374c4_object_simple,
#> data = nlmixr2data::pheno_sd, table = nlmixr2est::tableControl(),
#> directory = file.path(targets::tar_config_get("store"), "user/nlmixr2"),
#> est = "saem", control = list())
#> format: rds
#> repository: local
#> iteration method: vector
#> error mode: stop
#> memory mode: auto
#> storage mode: worker
#> retrieval mode: auto
#> deployment mode: worker
#> priority: 0
#> resources:
#> list()
#> cue:
#> seed: TRUE
#> file: TRUE
#> iteration: TRUE
#> repository: TRUE
#> format: TRUE
#> depend: TRUE
#> command: TRUE
#> mode: thorough
#> packages:
#> nlmixr2targets
#> nlmixr2est
#> library:
#> NULL
#> [[2]]$fit_simple
#> <tar_stem>
#> name: all_models_b0a374c4_fit_simple
#> description:
#> command:
#> nlmixr2_indirect(object = all_models_b0a374c4_object_simple,
#> data = all_models_b0a374c4_data_simple, est = "saem", control = list(),
#> directory = file.path(targets::tar_config_get("store"), "user/nlmixr2"),
#> error = "stop")
#> format: rds
#> repository: local
#> iteration method: vector
#> error mode: stop
#> memory mode: auto
#> storage mode: worker
#> retrieval mode: auto
#> deployment mode: worker
#> priority: 0
#> resources:
#> list()
#> cue:
#> seed: TRUE
#> file: TRUE
#> iteration: TRUE
#> repository: TRUE
#> format: TRUE
#> depend: TRUE
#> command: TRUE
#> mode: thorough
#> packages:
#> nlmixr2targets
#> nlmixr2est
#> library:
#> NULL
#> [[2]]$fit
#> <tar_stem>
#> name: all_models_b0a374c4
#> description:
#> command:
#> nlmixr_object_complicate(fit = all_models_b0a374c4_fit_simple,
#> object = pheno2, data = nlmixr2data::pheno_sd)
#> format: rds
#> repository: local
#> iteration method: vector
#> error mode: stop
#> memory mode: auto
#> storage mode: worker
#> retrieval mode: auto
#> deployment mode: worker
#> priority: 0
#> resources:
#> list()
#> cue:
#> seed: TRUE
#> file: TRUE
#> iteration: TRUE
#> repository: TRUE
#> format: TRUE
#> depend: TRUE
#> command: TRUE
#> mode: thorough
#> packages:
#> nlmixr2targets
#> nlmixr2est
#> library:
#> NULL
#>
#> [[3]]
#> <tar_stem>
#> name: all_models
#> description:
#> command:
#> list(`Base model` = all_models_8ae20c5c, `Alternative residual error` = all_models_b0a374c4)
#> format: rds
#> repository: local
#> iteration method: vector
#> error mode: stop
#> memory mode: auto
#> storage mode: worker
#> retrieval mode: auto
#> deployment mode: worker
#> priority: 0
#> resources:
#> list()
#> cue:
#> seed: TRUE
#> file: TRUE
#> iteration: TRUE
#> repository: TRUE
#> format: TRUE
#> depend: TRUE
#> command: TRUE
#> mode: thorough
#> packages:
#> character(0)
#> library:
#> NULL